@@ -2,15 +2,13 @@
 
 __author__ = """Sebastian Weigand"""
 __email__ = "s.weigand.phy@gmail.com"
-__version__ = "0.4.0"
+__version__ = "0.5.1"
 
 import flake8
 
 from flake8_nb.flake8_integration.formatter import IpynbFormatter
 
-__all__ = [
-    IpynbFormatter.__name__,
-]
+__all__ = ["IpynbFormatter"]
 
 
 def save_cast_int(int_str: str) -> int:
